/*
Copyright (C) 2003 by Sean David Fleming

sean@ivec.org

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

The GNU GPL can also be found at http://www.gnu.org
*/

/* NB: property table is still assoc with model */
/* configs should link to relevant dialog & settings */
struct config_pak
{
gint id;
gchar *label;            /* tree label */
gpointer data;           /* computational code structure */
};

struct project_pak
{
gchar *label;          /* id / tree label */
gchar *path;           /* job directory */

GSList *models;        /* associated structures */
GSList *configs;       /* associated code configs */

GHashTable *data;      /* project specific data items */
};

/* prototypes */
gpointer project_new(const gchar *);
gpointer project_model_new(gpointer);
gpointer project_model_get(gint, gpointer);
gpointer project_data_get(gchar *, gpointer);

void project_model_add(struct model_pak *, gpointer);
void project_data_set(gchar *, gpointer, gpointer);

gchar *project_path(gpointer);

